import os, sys
import xml.etree.ElementTree as ET
import random

print(os.environ.get("SUMO_HOME"))
if 'SUMO_HOME' in os.environ:
    tools = os.path.join(os.environ['SUMO_HOME'], 'tools')
    sys.path.append(tools)
else:
    sys.exit("please declare environment variable 'SUMO_HOME'")

import traci
from sumolib import checkBinary

sumoBinary = checkBinary('sumo-gui')

def main():
    startSim()
    counter = 0
    while shouldContinueSim():
        rerouteCounters(counter)
        counter +=1
        traci.simulationStep()
    
    traci.close()



def rerouteCounters(
        counter             #counter to assign vehicle
    ):
    
    # get all vehicles passing edge
    queuelist = traci.edge.getLastStepVehicleIDs("E15")
    print("vehicles before junction (E15)")
    print(queuelist)
    print("vehicles in first lane (E16)")
    print(traci.edge.getLastStepVehicleIDs("E16"))
    print("vehicles in second lane (E18)")
    print(traci.edge.getLastStepVehicleIDs("E18"))
    
    # assign new counter/edges
    for vehicle in queuelist:
        if (counter%3 == 0):
            traci.vehicle.changeTarget(vehicle, "E16")
        if (counter%3 == 1):
            traci.vehicle.changeTarget(vehicle, "E18")
        if (counter%3 == 2):
            traci.vehicle.changeTarget(vehicle, "E20")
            
    """ uncomment to test reroute counters via changetarget """
    # for vehicle in queuelist:
        # traci.vehicle.changeTarget(vehicle, "E16")
        # traci.vehicle.changeTarget(vehicle, "E18")
        # traci.vehicle.changeTarget(vehicle, "E20")

      







def startSim():
    """Starts the simulation."""
    traci.start(
        [
            sumoBinary,
            '--net-file', './config/CargoReroute2.net.xml',
            '--route-files', './config/CargoVehDemand.rou.xml',
            '--delay', '66',
            '--gui-settings-file', './config/viewSettings.xml',
            '--junction-taz','1',
            '--step-length','1.1',
            '--start'
        ])

def shouldContinueSim():
    """Checks that the simulation should continue running.
    Returns:
        bool: `True` if vehicles exist on network. `False` otherwise.
    """
    numVehicles = traci.simulation.getMinExpectedNumber()
    return True if numVehicles > 0 else False


if __name__ == "__main__":
    main()